OC.L10N.register(
    "logreader",
    {
    "Error parsing log" : "Registro de análise de erros",
    "Caused by " : "Causado por",
    "Debug" : "Depurar ",
    "Info" : "Informações ",
    "Warning" : "Aviso",
    "Error" : "Erro",
    "Fatal" : "Fatal",
    "Copy" : "Copiar",
    "Copy raw" : "Copia básica",
    "Copy formatted" : "Cópia formatada",
    "No server logs" : "Sem registros no servidor",
    "One or more entries are hidden by the log level filter" : "Uma ou mais entradas estão escondidas pelo filtro de nível de registro",
    "Everything is working fine" : "Tudo está funcionando bem",
    "Level" : "Nível",
    "App" : "Aplicativo",
    "Message" : "Mensagem",
    "Time" : "Hora",
    "Load log file …" : "Carregar arquivo de log ... ",
    "Invalid log file" : "Arquivo de log inválido ",
    "Log levels" : "Níveis de registro",
    "Log content" : "Conteúdo do registro",
    "Live update" : "Atualização ao vivo",
    "Download logs" : "Registro de downloads",
    "Logging" : "Registro",
    "Log Reader" : "Leitor de Registro",
    "A log reader for Nextcloud" : "Um leitor de logs para Nextcloud",
    "Log reader for Nextcloud" : "Leitor de logs para Nextcloud"
},
"nplurals=2; plural=(n > 1);");
